"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.UsersTable = void 0;
const react_1 = __importDefault(require("react"));
const eui_1 = require("@elastic/eui");
exports.UsersTable = ({ users, editUserFlyover, rolesLoading, roles, relationUserRole }) => {
    const getRowProps = item => {
        const { id } = item;
        return {
            'data-test-subj': `row-${id}`,
            onClick: () => editUserFlyover(item),
        };
    };
    const columns = [
        {
            field: 'user',
            name: 'User',
            sortable: true,
            truncateText: true,
        },
        {
            field: 'full_name',
            name: 'Full name',
            sortable: true,
            truncateText: true,
        },
        {
            field: 'email',
            name: 'Email',
            sortable: true,
            truncateText: true,
        },
        {
            field: 'user',
            name: 'Roles',
            dataType: 'boolean',
            render: (user) => {
                if (rolesLoading) {
                    return react_1.default.createElement(eui_1.EuiLoadingSpinner, { size: "m" });
                }
                const userRoles = relationUserRole[user];
                if (!userRoles || !userRoles.length)
                    return react_1.default.createElement(react_1.default.Fragment, null);
                const tmpRoles = userRoles.map(role => {
                    return react_1.default.createElement(eui_1.EuiFlexItem, { grow: false },
                        react_1.default.createElement(eui_1.EuiBadge, { color: "secondary" }, roles[role]));
                });
                return react_1.default.createElement(eui_1.EuiFlexGroup, { wrap: true, responsive: false, gutterSize: "xs" }, tmpRoles);
            },
            sortable: true,
        },
    ];
    const sorting = {
        sort: {
            field: 'roles',
            direction: 'desc',
        },
    };
    const search = {
        box: {
            incremental: false,
            schema: true,
        },
    };
    return (react_1.default.createElement(eui_1.EuiInMemoryTable, { items: users, columns: columns, search: search, rowProps: getRowProps, pagination: true, sorting: sorting }));
};
