"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Users = void 0;
const react_1 = __importStar(require("react"));
const eui_1 = require("@elastic/eui");
const users_table_1 = require("./users-table");
const wazuh_security_1 = require("../../../factories/wazuh-security");
const edit_user_1 = require("./edit-user");
const wz_request_1 = require("../../../react-services/wz-request");
const redux_1 = require("redux");
const react_redux_1 = require("react-redux");
const hocs_1 = require("../../common/hocs");
const prompt_no_security_plugin_1 = require("./prompt-no-security-plugin");
const mapStateToProps = state => ({ currentPlatform: state.appStateReducers.currentPlatform });
exports.Users = redux_1.compose(react_redux_1.connect(mapStateToProps), hocs_1.withGuard((props) => {
    return props.currentPlatform === 'elastic';
}, prompt_no_security_plugin_1.PromptNoSecurityPluginUsers))(() => {
    const [isEditFlyoutVisible, setIsEditFlyoutVisible] = react_1.useState(false);
    const [editingUser, setEditingUser] = react_1.useState(false);
    const [users, setUsers] = react_1.useState([]);
    const [rolesLoading, setRolesLoading] = react_1.useState(true);
    const [relationUserRole, setRelationUserRole] = react_1.useState({});
    const [roles, setRoles] = react_1.useState({});
    const [securityError, setSecurityError] = react_1.useState(false);
    const getUsers = async () => {
        const loadRoles = async (users) => {
            const rolesData = await wz_request_1.WzRequest.apiReq('GET', '/security/roles', {});
            const roles = ((rolesData.data || {}).data || {}).affected_items || [];
            const rolesObject = {};
            roles.forEach(item => {
                rolesObject[item.id] = item.name;
            });
            setRoles(rolesObject);
            const rulesData = await wz_request_1.WzRequest.apiReq('GET', '/security/rules', {});
            const rules = ((rulesData.data || {}).data || {}).affected_items || [];
            const userRelationRole = {};
            users.forEach(item => {
                const filteredRule = rules.filter(x => x.name === `wui_${item.user}` || item.user === 'elastic' || item.user === 'admin');
                if (filteredRule.length) {
                    userRelationRole[item.user] = filteredRule[0].roles;
                }
            });
            setRelationUserRole(userRelationRole);
            setRolesLoading(false);
        };
        try {
            const wazuhSecurity = new wazuh_security_1.WazuhSecurity();
            const wazuh_users = await wazuhSecurity.security.getUsers();
            const users = wazuh_users.map((item, idx) => {
                return { id: idx, user: item.username, roles: [], full_name: item.full_name, email: item.email };
            });
            setUsers(users);
            loadRoles(users);
        }
        catch (error) {
            setSecurityError(true);
        }
    };
    react_1.useEffect(() => {
        getUsers();
    }, []);
    let editFlyout;
    const closeEditFlyout = async () => {
        await getUsers();
        setIsEditFlyoutVisible(false);
    };
    if (securityError) {
        return react_1.default.createElement(eui_1.EuiEmptyPrompt, { iconType: "securityApp", title: react_1.default.createElement("h2", null, "You need permission to manage users"), body: react_1.default.createElement("p", null, "Contact your system administrator.") });
    }
    if (isEditFlyoutVisible) {
        editFlyout = (react_1.default.createElement(eui_1.EuiOverlayMask, { headerZindexLocation: "below", onClick: () => { setIsEditFlyoutVisible(false); } },
            react_1.default.createElement(edit_user_1.EditUser, { currentUser: editingUser, closeFlyout: closeEditFlyout, userRoles: relationUserRole[editingUser.user] || [], rolesObject: roles })));
    }
    const showEditFlyover = (item) => {
        setEditingUser(item);
        setIsEditFlyoutVisible(true);
    };
    return (react_1.default.createElement(eui_1.EuiPageContent, null,
        react_1.default.createElement(eui_1.EuiPageContentHeader, null,
            react_1.default.createElement(eui_1.EuiPageContentHeaderSection, null,
                react_1.default.createElement(eui_1.EuiTitle, null,
                    react_1.default.createElement("h2", null, "Users"))),
            react_1.default.createElement(eui_1.EuiPageContentHeaderSection, null)),
        react_1.default.createElement(eui_1.EuiPageContentBody, null,
            react_1.default.createElement(users_table_1.UsersTable, { users: users, editUserFlyover: showEditFlyover, rolesLoading: rolesLoading, relationUserRole: relationUserRole, roles: roles })),
        editFlyout));
});
